@@ -211,6 +211,22 @@ class Matrix:
         else:
             raise Exception("It Should be a Square Matrix.")
 
+    def trace(self):
+        """
+        Returns the sum of all Diagonal Elements of the Matrix.
+        """
+        return sum(diag(self))
+
+    def flatten(self):
+        """
+        Converts the Matrix to a 1-D List.
+        """
+        lst = []
+        for i in range(self.rows):
+            for j in range(self.columns):
+                lst.append(self.matrix[i][j])
+        return lst
+
 
 def matSum(m1, m2):
     """
@@ -411,6 +427,7 @@ if __name__ == '__main__':
     a = Matrix(4, 4)
     a.listTomatrix([0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0])
     b = Matrix(4, 4)
-    b.listTomatrix([1, 10, 0, 2, 0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0])
-    print(a.orthogonalCheck())
-    matMul(a, b).printMatrix()
+    b.listTomatrix([1, 10, 0, 2, 0, 1, 1, 0, 1, 1, 0, 0, 0, 1, 0, 1])
+    b.printMatrix()
+    print(b.trace())
+    print(b.flatten())
\ No newline at end of file
